# Generated by roxygen2: do not edit by hand

S3method("[",aoe_result)
S3method(aoe_sample,aoe_border_result)
S3method(aoe_sample,aoe_result)
S3method(aoe_sample,default)
S3method(plot,aoe_border_result)
S3method(plot,aoe_result)
S3method(print,aoe_area_result)
S3method(print,aoe_border_result)
S3method(print,aoe_expand_result)
S3method(print,aoe_result)
S3method(print,aoe_summary_result)
S3method(summary,aoe_result)
export(aoe)
export(aoe_area)
export(aoe_border)
export(aoe_expand)
export(aoe_geometry)
export(aoe_sample)
export(aoe_summary)
export(get_country)
importFrom(grDevices,rgb)
importFrom(graphics,legend)
importFrom(methods,as)
importFrom(stats,setNames)
